@@ -1,9 +1,11 @@
+from typing import TYPE_CHECKING
+
+from .hkObject import hkObject
+from ..enums.EdgeFlagBits import EdgeFlagBits
 from ...binary import BinaryReader, BinaryWriter
 from ...binary.types import Float16, Int32, UInt8, UInt32
-from ..enums.EdgeFlagBits import EdgeFlagBits
-from .hkObject import hkObject
 
-if False:
+if TYPE_CHECKING:
     from ...hkfile import HKFile
     from ...container.util.hkobject import HKObject
 
